pygcgopt: Python interface and modeling environment for GCG
===========================================================

Description
-----------

Python interface and modeling environment for GCG

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/PyGCGOpt/

